@@ -188,7 +188,7 @@ class FluxAgent:
                             registered = True
             except (asyncio.exceptions.TimeoutError, ClientConnectorError):
                 self.log.error(
-                    "Unable to connect to local fluxagent... trying again in 5"
+                    f"Unable to connect to local fluxagent @ {url}... trying again in 5"
                 )
                 await asyncio.sleep(5)
         self.log.info("Successfully registered with primary agent")
